<?php
/**
 * Plugin Name: Advanced Sidebar Menu PRO
 * Plugin URI: https://onpointplugins.com/advanced-sidebar-menu-pro/
 * Description: Adds additional functionality to the Advanced Sidebar Menu plugin.
 * Author: OnPoint Plugins
 * Version: 8.1.4
 * Author URI: https://onpointplugins.com
 *
 * @package advanced-sidebar-menu-pro
 */

if ( defined( 'ADVANCED_SIDEBAR_MENU_PRO_VERSION' ) ) {
	return;
}

define( 'ADVANCED_SIDEBAR_MENU_PRO_VERSION', '8.1.4' );
define( 'ADVANCED_SIDEBAR_MENU_REQUIRED_BASIC_VERSION', '8.0.0' );

define( 'ADVANCED_SIDEBAR_MENU_PRO_DIR', plugin_dir_path( __FILE__ ) );
define( 'ADVANCED_SIDEBAR_MENU_PRO_URL', plugin_dir_url( __FILE__ ) );
define( 'ADVANCED_SIDEBAR_MENU_PRO_OPTIONS_DIR', ADVANCED_SIDEBAR_MENU_PRO_DIR . 'src/widget-options/' );

use Advanced_Sidebar_Menu\Factory;
use Advanced_Sidebar_Menu\Menus\Navigation;
use Advanced_Sidebar_Menu\Meta\Title;
use Advanced_Sidebar_Menu\Nav_Menu\Item;
use Advanced_Sidebar_Menu\Nav_Menu\Objects;
use Advanced_Sidebar_Menu\Pro_Scripts;
use Advanced_Sidebar_Menu\Walkers\Posts;
use Advanced_Sidebar_Menu\Widget\Navigation_Menu;
use Advanced_Sidebar_Menu\Widget_Options\Category\Display_Everywhere as Category_Display_Everywhere;
use Advanced_Sidebar_Menu\Widget_Options\Category\Display_Posts;
use Advanced_Sidebar_Menu\Widget_Options\Category\Order_By;
use Advanced_Sidebar_Menu\Widget_Options\Category\Taxonomy;
use Advanced_Sidebar_Menu\Widget_Options\Page\Current_Page_Parent_Only;
use Advanced_Sidebar_Menu\Widget_Options\Page\Display_Everywhere;
use Advanced_Sidebar_Menu\Widget_Options\Page\Limit_Levels;
use Advanced_Sidebar_Menu\Widget_Options\Page\Post_Type;
use Advanced_Sidebar_Menu\Widget_Options\Shared\Accordion;
use Advanced_Sidebar_Menu\Widget_Options\Shared\Style_Targeting;
use Advanced_Sidebar_Menu\Widget_Options\Shared\Styles;
use Advanced_Sidebar_Menu\Widget_Options\Widget_Options_Abstract;

add_action( 'plugins_loaded', 'advanced_sidebar_menu_pro_translate' );
/**
 * Load Translations
 *
 * @return void
 */
function advanced_sidebar_menu_pro_translate() {
	load_plugin_textdomain( 'advanced-sidebar-menu', false, 'advanced-sidebar-menu-pro/languages' );
}

/**
 * Load the plugin
 *
 * @return void
 */
function advanced_sidebar_menu_pro_init() {
	if ( ! defined( 'ADVANCED_SIDEBAR_BASIC_VERSION' ) || version_compare( ADVANCED_SIDEBAR_MENU_REQUIRED_BASIC_VERSION, ADVANCED_SIDEBAR_BASIC_VERSION, '>' ) ) {
		add_action( 'admin_notices', 'advanced_sidebar_menu_pro_basic_version_warning' );

		return;
	}

	// Core.
	Factory::init();
	Pro_Scripts::init();
	// Meta.
	Title::init();
	// Category options.
	Taxonomy::init();
	Order_By::init();
	Category_Display_Everywhere::init();
	Display_Posts::init();
	// Page options.
	Post_Type::init();
	Current_Page_Parent_Only::init();
	Limit_Levels::init();
	Display_Everywhere::init();
	// Shared options.
	Accordion::init();
	Style_Targeting::init();
	Styles::init();
}

add_action( 'plugins_loaded', 'advanced_sidebar_menu_pro_init', 11 );
/**
 * Load plugin update functionality.
 */
add_action( 'plugins_loaded', function () {
	require __DIR__ . '/src/Update.php';
	new OnPoint_Plugins\Pro_Plugins\Update( 'advanced-sidebar-menu-pro', ADVANCED_SIDEBAR_MENU_PRO_DIR );
} );

/**
 * Autoload classes from PSR4 src directory
 * Mirrored after Composer dump-autoload for performance
 *
 * @param string $class - class to load.
 *
 * @since 2.4.0
 *
 * @return void
 */
function advanced_sidebar_menu_pro_autoload( $class ) {
	$classes = [
		// Core.
		Factory::class                     => 'Factory.php',
		Pro_Scripts::class                 => 'Pro_Scripts.php',

		// Meta.
		Title::class                       => 'Meta/Title.php',

		// Nav menu.
		Item::class                        => 'Nav_Menu/Item.php',
		Objects::class                     => 'Nav_Menu/Objects.php',

		// Widget options.
		Widget_Options_Abstract::class     => 'Widget_Options/Widget_Options_Abstract.php',

		// Category options.
		Order_By::class                    => 'Widget_Options/Category/Order_By.php',
		Category_Display_Everywhere::class => 'Widget_Options/Category/Display_Everywhere.php',
		Display_Posts::class               => 'Widget_Options/Category/Display_Posts.php',
		Taxonomy::class                    => 'Widget_Options/Category/Taxonomy.php',

		// Menus.
		Navigation::class                  => 'Menus/Navigation.php',

		// Page options.
		Current_Page_Parent_Only::class    => 'Widget_Options/Page/Current_Page_Parent_Only.php',
		Display_Everywhere::class          => 'Widget_Options/Page/Display_Everywhere.php',
		Limit_Levels::class                => 'Widget_Options/Page/Limit_Levels.php',
		Post_Type::class                   => 'Widget_Options/Page/Post_Type.php',

		// Shared.
		Accordion::class                   => 'Widget_Options/Shared/Accordion.php',
		Styles::class                      => 'Widget_Options/Shared/Styles.php',
		Style_Targeting::class             => 'Widget_Options/Shared/Style_Targeting.php',

		// Walkers.
		Posts::class                       => 'Walkers/Posts.php',

		// Widgets.
		Navigation_Menu::class             => 'Widget/Navigation_Menu.php',
	];
	if ( isset( $classes[ $class ] ) ) {
		require __DIR__ . '/src/' . $classes[ $class ];
	}
}

spl_autoload_register( 'advanced_sidebar_menu_pro_autoload' );

/**
 * Display a warning if we don't have the required basic version installed
 *
 * @return void
 */
function advanced_sidebar_menu_pro_basic_version_warning() {
	?>
	<div class="error">
		<p>
			<?php
			/* translators: {%1$s}[<a>]{%2$s}[</a>] URL to plugin on wordpress.org */
			printf( esc_html_x( 'Advanced Sidebar Menu Pro requires the basic version of %1$sAdvanced Sidebar Menu %3$s+%2$s to be installed and active.', '{<a>}{</a>}', 'advanced-sidebar-menu' ), '<a target="_blank" href="https://wordpress.org/plugins/advanced-sidebar-menu/">', '</a>', esc_attr( ADVANCED_SIDEBAR_MENU_REQUIRED_BASIC_VERSION ) );
			?>
		</p>
	</div>
	<?php
}
