<?php

namespace Advanced_Sidebar_Menu\Widget_Options\Page;

use Advanced_Sidebar_Menu\Menus\Page;
use Advanced_Sidebar_Menu\Traits\Singleton;
use Advanced_Sidebar_Menu\Widget_Options\Widget_Options_Abstract;

/**
 * Limit the levels of pages in the output when "Always display child pages" is not checked.
 *
 * Basically all we do here is return the value from the option that is hidden when the PRO
 * version is not active, and the "Always Display" option is unchecked.
 *
 * We used to have a field here, so in the meantime we return the value if set.
 *
 * @author OnPoint Plugins
 */
class Limit_Levels extends Widget_Options_Abstract {
	use Singleton;

	/**
	 * Actions and filters.
	 *
	 * @return void
	 */
	protected function hook() {
		add_filter( 'advanced-sidebar-menu/menus/page/levels', [ $this, 'limit_page_levels' ], 10, 4 );
		add_filter( 'advanced-sidebar-menu/widget/page/hide-levels-field', '__return_false' );
	}


	/**
	 * If we have a limit set we limit the levels via filter.
	 *
	 * @param int   $levels      - Current levels to display.
	 * @param array $widget_args - Widget arguments.
	 * @param array $instance    - Widget settings.
	 * @param Page  $menu        - Menu class.
	 *
	 * @return int
	 */
	public function limit_page_levels( $levels, $widget_args, array $instance, Page $menu ) {
		// This option does not apply when display all is checked.
		if ( empty( $instance[ Page::LEVELS ] ) || $menu->display_all() ) {
			return $levels;
		}

		// Very old values.
		if ( is_array( $instance[ Page::LEVELS ] ) ) {
			return (int) array_shift( $instance[ Page::LEVELS ] ) - 1;
		}

		// Use the same widget value that is saved when "Display All" is checked.
		// Only the PRO version allows using this value when "Display All" is not checked.
		// Subtract 1 level to account for the first level children.
		return (int) $instance[ Page::LEVELS ] - 1;
	}

}
