<?php

namespace Advanced_Sidebar_Menu\Widget_Options\Shared;

use Advanced_Sidebar_Menu\Factory;
use Advanced_Sidebar_Menu\Menus\Menu_Abstract;
use Advanced_Sidebar_Menu\Traits\Singleton;
use Advanced_Sidebar_Menu\Widget\Widget_Abstract;
use Advanced_Sidebar_Menu\Widget_Options\Widget_Options_Abstract;

/**
 * Style options and CSS rendering for all widgets.
 *
 * @since  3.3.0
 */
class Styles extends Widget_Options_Abstract {
	use Singleton;

	const NAME = true;

	/**
	 * Fields for the widget.
	 *
	 * @var array
	 */
	protected $fields = [];


	/**
	 * Advanced_Sidebar_Menu\Widget_Options\Shared\Advanced_Sidebar_Menu_Pro__Widget_Options__Shared__Styles
	 * constructor.
	 */
	public function __construct() {
		$this->fields = [
			'parent_page_color'           => __( 'Highest level parent color', 'advanced-sidebar-menu' ),
			'parent_page_bg_color'        => __( 'Highest level parent background color', 'advanced-sidebar-menu' ),
			'parent_page_font_weight'     => __( 'Highest level parent font weight', 'advanced-sidebar-menu' ),
			'parent_page_font_size'       => __( 'Highest level parent font size', 'advanced-sidebar-menu' ) . ' (px)',

			'divider',
			'child_page_color'            => __( 'Child color', 'advanced-sidebar-menu' ),
			'child_page_bg_color'         => __( 'Child background color', 'advanced-sidebar-menu' ),
			'child_page_font_weight'      => __( 'Child font weight', 'advanced-sidebar-menu' ),
			'child_page_font_size'        => __( 'Child font size', 'advanced-sidebar-menu' ) . ' (px)',

			'divider',
			'grandchild_page_color'       => __( 'Grandchild color', 'advanced-sidebar-menu' ),
			'grandchild_page_bg_color'    => __( 'Grandchild background color', 'advanced-sidebar-menu' ),
			'grandchild_page_font_weight' => __( 'Grandchild font weight', 'advanced-sidebar-menu' ),
			'grandchild_page_font_size'   => __( 'Grandchild font size', 'advanced-sidebar-menu' ) . ' (px)',

			'current_page_color'              => __( 'Current item color', 'advanced-sidebar-menu' ),
			'current_page_bg_color'           => __( 'Current item background color', 'advanced-sidebar-menu' ),
			'current_page_font_weight'        => __( 'Current item font weight', 'advanced-sidebar-menu' ),
			'current_page_font_size'          => __( 'Current item font size', 'advanced-sidebar-menu' ) . ' (px)',

			'divider',
			'current_page_parent_color'       => __( 'Current item parent color', 'advanced-sidebar-menu' ),
			'current_page_parent_bg_color'    => __( 'Current item parent background color', 'advanced-sidebar-menu' ),
			'current_page_parent_font_weight' => __( 'Current item parent font weight', 'advanced-sidebar-menu' ),
			'current_page_parent_font_size'   => __( 'Current item parent font size', 'advanced-sidebar-menu' ) . ' (px)',
		];
	}


	/**
	 * Actions.
	 */
	protected function hook() {
		add_action( 'advanced-sidebar-menu/menus/page/render', [ $this, 'render' ] );
		add_action( 'advanced-sidebar-menu/widget/page/after-form', [ $this, 'render_fields' ], 10, 2 );

		add_action( 'advanced-sidebar-menu/menus/category/render', [ $this, 'render' ] );
		add_action( 'advanced-sidebar-menu/widget/category/after-form', [ $this, 'render_fields' ], 10, 2 );

		add_action( 'advanced-sidebar-menu/menus/navigation/render', [ $this, 'render' ] );
		add_action( 'advanced-sidebar-menu/widget/navigation-menu/after-form', [ $this, 'render_fields' ], 10, 2 );
	}


	/**
	 * Output the styles
	 *
	 * @param Menu_Abstract $menu - Current menu.
	 *
	 * @return void
	 */
	public function render( Menu_Abstract $menu ) {
		$widget_args = $menu->get_widget_args();
		$instance = $menu->get_widget_instance();
		$out = null;

		// The CSS id.
		$css_id = '#' . $widget_args['widget_id'] . Factory::CSS_SELECTOR_APPEND . ' ';

		$sections = [
			'parent_page',
			'child_page',
			'grandchild_page',
			'current_page',
			'current_page_parent',
		];

		$styles = [];
		foreach ( $sections as $section ) {
			$styles[ $section ] = '';

			if ( ! empty( $instance[ $section . '_color' ] ) ) {
				$styles[ $section ] .= 'color: ' . $instance[ $section . '_color' ] . ' !important;';
			}

			if ( ! empty( $instance[ $section . '_bg_color' ] ) ) {
				$styles[ $section ] .= 'background-color: ' . $instance[ $section . '_bg_color' ] . ' !important; ';
			}

			if ( ! empty( $instance[ $section . '_font_weight' ] ) ) {
				$styles[ $section ] .= 'font-weight: ' . $instance[ $section . '_font_weight' ] . ' !important; ';
			}

			if ( ! empty( $instance[ $section . '_font_size' ] ) ) {
				$styles[ $section ] .= 'font-size: ' . $instance[ $section . '_font_size' ] . 'px !important;';
			}
		}

		if ( ! empty( $instance[ Style_Targeting::BULLET_STYLE ] ) ) {
			$out .= $css_id . 'li{ list-style-type: ' . $instance[ Style_Targeting::BULLET_STYLE ] . ' !important; list-style: ' . $instance['bullet_style'] . '!important;}';
		}

		if ( ! empty( $styles['parent_page'] ) ) {
			$out .= $css_id . '.parent-sidebar-menu > li > a{' . $styles['parent_page'] . '}';
		}
		if ( ! empty( $styles['child_page'] ) ) {
			$out .= $css_id . '.child-sidebar-menu > li > a{' . $styles['child_page'] . '}';
		}
		if ( ! empty( $styles['grandchild_page'] ) ) {
			$out .= $css_id . '.child-sidebar-menu .children li a{' . $styles['grandchild_page'] . '}';
		}
		if ( ! empty( $styles['current_page'] ) ) {
			if ( ! $menu->checked( Style_Targeting::APPLY_CURRENT_STYLES ) ) {
				$out .= $css_id . '.child-sidebar-menu li.page_item.current_page_item > a{' . $styles['current_page'] . '}';
				$out .= $css_id . '.child-sidebar-menu li.menu-item.current-menu-item > a{' . $styles['current_page'] . '}';
				$out .= $css_id . '.child-sidebar-menu li.cat-item.current-cat > a{' . $styles['current_page'] . '}';
			} else {
				$out .= $css_id . 'li.page_item.current_page_item > a{' . $styles['current_page'] . '}';
				$out .= $css_id . 'li.menu-item.current-menu-item > a{' . $styles['current_page'] . '}';
				$out .= $css_id . 'li.cat-item.current-cat > a{' . $styles['current_page'] . '}';
			}
		}
		if ( ! empty( $styles['current_page_parent'] ) ) {
			if ( ! $menu->checked( Style_Targeting::APPLY_PARENT_STYLES ) ) {
				$out .= $css_id . '.child-sidebar-menu li.page_item.current_page_parent > a{' . $styles['current_page_parent'] . '}';
				$out .= $css_id . '.child-sidebar-menu li.menu-item.current-menu-parent > a{' . $styles['current_page_parent'] . '}';
				$out .= $css_id . '.child-sidebar-menu li.cat-item.current-cat-parent > a{' . $styles['current_page_parent'] . '}';
			} else {
				$out .= $css_id . 'li.page_item.current_page_parent > a{' . $styles['current_page_parent'] . '}';
				$out .= $css_id . 'li.menu-item.current-menu-parent > a{' . $styles['current_page_parent'] . '}';
				$out .= $css_id . 'li.cat-item.current-cat-parent > a{' . $styles['current_page_parent'] . '}';
			}
		}

		if ( $menu->checked( Style_Targeting::BLOCK_STYLE ) ) {
			$out .= Style_Targeting::instance()->get_block_styles( $css_id, $instance, $menu );
			if ( $menu->checked( Style_Targeting::BORDER ) ) {
				$out .= Style_Targeting::instance()->get_border_styles( $css_id, $instance );
			}
		}

		$out = apply_filters( 'advanced-sidebar-menu-pro/widget-options/shared/styles/output', $out, $styles, $menu, $css_id );

		if ( null !== $out ) {
			printf( "<style id='%s-inline-css' type='text/css'>\n%s\n</style>\n", esc_attr( $widget_args['widget_id'] ), $out ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}




	/**
	 * List of available font weights.
	 *
	 * @return array
	 */
	public function get_font_weights() {
		$weights = [
			'normal'  => __( 'Normal', 'advanced-sidebar-menu' ),
			'bold'    => __( 'Bold', 'advanced-sidebar-menu' ),
			'lighter' => __( 'Light', 'advanced-sidebar-menu' ),
		];

		return apply_filters( 'advanced-sidebar-menu/styles/font-weights', $weights );
	}


	/**
	 * Render the widget fields.
	 *
	 * @param array           $instance - Widget settings.
	 * @param Widget_Abstract $widget   - Widget class.
	 *
	 * @return mixed|void
	 */
	public function render_fields( array $instance, $widget ) {
		foreach ( $this->fields as $_key => $_label ) {
			if ( ! isset( $instance[ $_key ] ) ) {
				$instance[ $_key ] = false;
			}
		}

		?>
		<div
			class="advanced-sidebar-menu-full-width"
			style="width:100%; display:none;"
			data-advanced-sidebar-menu-hide="0">
			<div class="advanced-sidebar-menu-column-box" style="text-align: center;">
				<div
					class="button-secondary widefat"
					data-js="advanced-sidebar-menu-pro/widget/show-styles"
					data-target="<?php echo esc_js( $widget->id ); ?>-css">
					<?php esc_html_e( 'Click to show styles', 'advanced-sidebar-menu' ); ?>
				</div>
			</div>
		</div>

		<div id="<?php echo esc_attr( $widget->id ); ?>-css" data-advanced-sidebar-menu-hide="1" class="asm-css-styles">
			<div class="advanced-sidebar-menu-column">
				<div class="advanced-sidebar-menu-column-box">
					<?php
					$count = 1;
					foreach ( $this->fields as $field => $_label ) {
						$count ++;
						if ( 16 === $count ) {
							echo '</div></div><div class="advanced-sidebar-menu-column advanced-sidebar-menu-column-right"><div class="advanced-sidebar-menu-column-box">';
						}
						if ( 'divider' === $_label ) {
							echo '</div><div class="advanced-sidebar-menu-column-box">';
							continue;
						}
						?>
						<p>
							<label>
								<?php echo esc_html( $_label ); ?>:
							</label>

							<?php
							// Font weights.
							if ( strpos( $field, 'weight' ) !== false ) {
								?>
								<select
									name="<?php echo esc_attr( $widget->get_field_name( $field ) ); ?>"
									id="<?php echo esc_attr( $widget->get_field_id( $field ) ); ?>">
									<option value="">
										<?php esc_html_e( '- default -', 'advanced-sidebar-menu' ); ?>
									</option>
									<?php
									foreach ( $this->get_font_weights() as $weight => $__label ) {
										printf( '<option value="%s" %s>%s</option>', esc_attr( $weight ), selected( $instance[ $field ], $weight ), esc_html( $__label ) );
									}
									?>
								</select>
								<?php
								// Colors.
							} elseif ( strpos( $field, 'color' ) !== false ) {
								printf( '<input type="text" name="%s" value="%s" id="%s" class="asm-color-select">', esc_attr( $widget->get_field_name( $field ) ), esc_html( $instance[ $field ] ), esc_attr( $widget->get_field_id( $field ) ) );
								// Size.
							} elseif ( strpos( $field, 'size' ) !== false ) {
								printf( '<input type="number" step="1" min="2" name="%s" value="%s" id="%s" class="size-range" size="5" style="width: 75px">', esc_attr( $widget->get_field_name( $field ) ), esc_html( $instance[ $field ] ), esc_attr( $widget->get_field_id( $field ) ) );
							}
							?>
						</p>
						<?php
					}
					?>
				</div>
			</div>
			<div class="advanced-sidebar-menu-full-width"><!-- Clear --></div>
		</div>
		<?php
	}
}
